@@ -349,7 +349,8 @@ void ButtonWidget::checkButtonCommand()
             confFileName = "/home/user/.qtirreco/themes/default/buttons/pause/button.conf";
             return;
         }
-        if(fileNameUnPressed.contains("power",Qt::CaseInsensitive) || fileNameUnPressed == "ONOFF" || fileNameUnPressed == "ON/OFF")
+        if(fileNameUnPressed.contains("power",Qt::CaseInsensitive) || fileNameUnPressed == "ONOFF" || fileNameUnPressed == "ON/OFF" ||
+           fileNameUnPressed == "on/off" || fileNameUnPressed == "On/Off")
         {
             fileNameUnPressed = "/home/user/.qtirreco/themes/default/buttons/power/unpressed.png";
             fileNamePressed = "/home/user/.qtirreco/themes/default/buttons/power/pressed.png";
