@@ -6,22 +6,20 @@ QtIrreco::QtIrreco(QWidget *parent)
 {
 
 
-   init = false;
-   showDatabaseButtons = false;
-   remoteNames = new QStringList();
-   lw = new LayoutWidget(this);
+    init = false;
+    showDatabaseButtons = false;
+    remoteNames = new QStringList();
+    lw = new LayoutWidget(this);
 
 
 
-   QDir dir;
-   if(!dir.exists("/home/user/MyDocs/qtirreco/Remotes")) {
-         QString remotes("mkdir /home/user/MyDocs/qtirreco/Remotes");
-         system(remotes.toAscii().data());
-      }
-   if(!dir.exists("/home/user/MyDocs/qtirreco/Devices")) {
-        QString devices("mkdir /home/user/MyDocs/qtirreco/Devices");
-        system(devices.toAscii().data());
-      }
+    QDir dir;
+    if(!dir.exists("/home/user/MyDocs/qtirreco/Remotes"))
+         system("mkdir /home/user/MyDocs/qtirreco/Remotes");
+
+    if(!dir.exists("/home/user/MyDocs/qtirreco/Devices"))
+        system("mkdir /home/user/MyDocs/qtirreco/Devices");
+
     if(!dir.exists("/home/user/MyDocs/qtirreco/themes"))
         dir.mkpath("/home/user/MyDocs/qtirreco/themes");
 
@@ -113,11 +111,20 @@ void QtIrreco::noRemotes()
 {
     activeRemote.clear();
     this->setWindowTitle("Please make a new remote!");
+    // Remove all files in Remotes
+    QDir dir(DEVICEREMOTES);
+    QStringList files = dir.entryList(QDir::Files);
+    for(int i=0;i<files.count(); i++) {
+        QFile file(DEVICEREMOTES + files.at(i));
+        file.remove();
+    }
+
     // Creates empty remotes.conf file
 
      QFile file(DEVICECONF);
 
-     if (!file.open(QIODevice::ReadWrite | QIODevice::Text)) {}
+     if (!file.open(QIODevice::ReadWrite | QIODevice::Text))
+         return;
      file.close();
 
      editButton->setDisabled(true);
