@@ -877,7 +877,7 @@ void ThemeManager::on_deletePushButton_clicked()
         }
     }
 
-    if(!remoteFiles.isEmpty()) {
+  /*  if(!remoteFiles.isEmpty()) {
         for(int i=0;i<remoteFiles.count();i++) {
             QFile remoteFile("/home/user/MyDocs/qtirreco/Remotes/"+remoteFiles.at(i));
 
@@ -895,7 +895,7 @@ void ThemeManager::on_deletePushButton_clicked()
             usedThemesByRemote.clear();
             remoteFile.close();
        }
-    }
+    }*/
 
     if(usedThemes.contains(themeToDelete,Qt::CaseInsensitive)) {
 
